%multi_value_trig_demo
% Function which finds multiple solutions of trignometric equations of the
% form t( f(x) ) = k where t is sin, cos or tan.
% NOTE f(x) must not have any multiple values over the range of x chosen.
%
% LAST UPDATED by Andy French Sept 2012

function multi_value_trig_demo

%Clear screen and display greeting message
clc;
disp(' ');
disp('  MULTI-VALUE TRIGONOMETRY')
disp('  Andy French. October 2013')
disp(' ' )

%%% GET INPUTS FROM COMMAND WINDOW %%%

%Define trig function
t = input('Define trig function sin cos or tan \n', 's' );

%Define k
disp(' ');
k = input('Define k s.t. trig function = k is the equation to solve \n' );

%Horizontal axis in degrees?
disp(' ');
deg_display = input( 'Display horizontal axis in degrees? \n' );

%Define argument of trig function t( f(x) ) IN RADIANS
disp(' ');
fx = input('Define argument of trig function t( f(x) ) IN RADIANS \n','s');

%Define inverse function of argument of trig function t( f(x) );
disp(' ');
gx = input('Define inverse function of argument of trig function t( f(x) ) \n','s');

%Define range IN RADIANS of allowed solutions
disp(' ');
xok = input('Define range IN RADIANS of allowed solutions \n');

%%

%%% HARD CODED INPUTS %%%

%Fontsize
fsize = 12;

%Number of data points
N = 1000;

%%

%Get solutions and vectors of x,y,f
[x,xx,y,f] = multi_value_trig( t, fx, gx, k, xok, N );

%Print solutions in degrees
disp(' ')
disp(['Solutions to y = ',t,'( ',fx,' ) = ',num2str(k),...
    ' in range [',num2str(180*xok(1)/pi),',',num2str(180*xok(2)/pi),'] are...'] )
for n=1:length(xx)
    disp( [ num2str(180*xx(n)/pi), ' deg = ',num2str(xx(n)),' rad'] );
end
disp(' ');

%Plot trig function vs x
figure('color',[1 1 1])
if deg_display ==1
    x = x*180/pi;
    xx = xx*180/pi;
end
plot( x, y, 'b');
hold on;
plot( [x(1),x(end)],[k,k] ,'r');
ylimit = get(gca,'ylim');
plot( xx,k*ones(1,length(xx)),'r*')
if deg_display ==1
    xlabel('x /degrees','fontsize',fsize)
else
    xlabel('x /radians','fontsize',fsize)
end
ylabel(['y = ',t,'( ',strrep(fx,'^','\^'),' )'],'fontsize',fsize)
title(['y = ',t,'( ',strrep(fx,'^','\^'),' )'],'fontsize',fsize)
set(gca,'fontsize',fsize)
axis tight
grid on
ylimit = [max( [min(y),-max(x)] ), min( [max(y),max(x)] ) ];
set(gca,'ylim',ylimit)
set(gca,'xlim',[min(x),max(x)])
print( gcf, '-r300', '-dpng','multi_valued_trig' )

%End of code