%trigsolver
% Example solution of sin(f(x)) = sin(g(x))
%
% LAST UPDATED by Andy French June 2017

function trigsolver

% sin(3x) = sin(2x+1)

%Fontsize
fsize = 16;

%Define vector of x corodinates /radians
N = 1000;
xmin = 0;
xmax = 4*pi;
x = linspace(xmin,xmax,N);

%Define trig functions to plot
yL = sin(3*x);
yR = sin(2*x + 1);

%Determine solutions
kmax = floor( 0.5*((5*xmax+1)/pi - 1) );
kmin = ceil( 0.5*((5*xmin+1)/pi - 1) );
k = kmin:kmax;
xs = ((2*k+1)*pi - 1)/5;
nmax = floor( (xmax-1)/(2*pi) );
nmin = ceil( (xmin-1)/(2*pi) );
n = nmin:nmax;
xs = [xs,2*n*pi+1];
ys = sin(3*xs);

plot(x,yL,x,yR);
set(gca,'fontsize',fsize)
legend({'y = sin(3x)','y = sin(2x+1)'},'fontsize',fsize);
xlabel('x /radians','fontsize',fsize)
ylabel('y','fontsize',fsize);
title('Solution of sin(3x) = sin(2x+1)','fontsize',fsize);
hold on;
plot(xs,ys,'r*');
grid on;
xlim([xmin,xmax]);
print(gcf,'trigsolver1.png','-dpng','-r300');
close(gcf);

%%

% 3sin(2x) - sqrt(3)*cos(2x) = 5/2

%Fontsize
fsize = 16;

%Define vector of x corodinates /radians
N = 1000;
xmin = 0;
xmax = 4*pi;
x = linspace(xmin,xmax,N);

%Define trig functions to plot
y1 = 3*sin(2*x)- sqrt(3)*cos(2*x);
y2 = sqrt(3)*ones(size(x));

%Determine solutions
nmin = ceil( xmin/pi - 1/6 );
nmax = floor( xmax/pi - 1/6 );
n = nmin:nmax;
xs = (1/6 + n)*pi;
mmin = ceil( xmin/pi - 1/2  );
mmax = floor( xmax/pi - 1/2  );
m = mmin:mmax;
xs = [xs,(1/2+m)*pi];
ys = 3*sin(2*xs)- sqrt(3)*cos(2*xs);

plot(x,y1,x,y2);
set(gca,'fontsize',fsize)
legend({'y = 3sin(2x) - sqrt(3)*cos(2x)','y = sqrt(3)'},'fontsize',fsize);
xlabel('x /radians','fontsize',fsize)
ylabel('y','fontsize',fsize);
title('Solution of 3sin(2x) - sqrt(3)*cos(2x) = sqrt(3)','fontsize',fsize);
hold on;
plot(xs,ys,'r*');
grid on;
xlim([xmin,xmax]);
print(gcf,'trigsolver2.png','-dpng','-r300');
close(gcf);

% sin(5x) = -sin(x - pi/4)

%Fontsize
fsize = 16;

%Define vector of x corodinates /radians
N = 1000;
xmin = 0;
xmax = 4*pi;
x = linspace(xmin,xmax,N);

%Define trig functions to plot
yL = sin(5*x);
yR = -sin(x - pi/4);

%Determine solutions
kmax = floor( ( (4*xmax+pi/4)/pi -1)/2 );
kmin = ceil( ((4*xmin+pi/4)/pi -1)/2 );
k = kmin:kmax;
xs = ((2*k+1)*pi - pi/4)/4;
nmax = floor( (6*xmax-pi/4)/(2*pi) );
nmin = ceil( (6*xmin-pi/4)/(2*pi) );
n = nmin:nmax;
xs = [xs,(2*n*pi + pi/4)/6];
ys = sin(5*xs);

plot(x,yL,x,yR);
set(gca,'fontsize',fsize)
legend({'y = sin(5x)','y = -sin(x - pi/4)'},'fontsize',fsize);
xlabel('x /radians','fontsize',fsize)
ylabel('y','fontsize',fsize);
title('Solution of sin(5x) = -sin(x - pi/4)','fontsize',fsize);
hold on;
plot(xs,ys,'r*');
grid on;
xlim([xmin,xmax]);
print(gcf,'trigsolver3.png','-dpng','-r300');
close(gcf);

%%

% cos(3x) = cos(2x)

%Fontsize
fsize = 16;

%Define vector of x corodinates /radians
N = 1000;
xmin = 0;
xmax = 4*pi;
x = linspace(xmin,xmax,N);

%Define trig functions to plot
yL = cos(3*x);
yR = cos(2*x);

%Determine solutions
kmax = floor( 5*xmax/(2*pi) );
kmin = ceil( 5*xmin/(2*pi) );
k = kmin:kmax;
xs = (2/5)*k*pi;
nmax = floor( xmax/(2*pi) );
nmin = ceil( xmin/(2*pi) );
n = nmin:nmax;
xs = [xs,2*n*pi];
ys = cos(3*xs);

plot(x,yL,x,yR);
set(gca,'fontsize',fsize)
legend({'y = cos(3x)','y = cos(2x)'},'fontsize',fsize);
xlabel('x /radians','fontsize',fsize)
ylabel('y','fontsize',fsize);
title('Solution of cos(3x) = cos(2x)','fontsize',fsize);
hold on;
plot(xs,ys,'r*');
grid on;
xlim([xmin,xmax]);
print(gcf,'trigsolver4.png','-dpng','-r300');
close(gcf);

%%

% cos(2x+1)= -cos(x-1)

%Fontsize
fsize = 16;

%Define vector of x corodinates /radians
N = 1000;
xmin = 0;
xmax = 4*pi;
x = linspace(xmin,xmax,N);

%Define trig functions to plot
yL = cos(2*x+1);
yR = -cos(x - 1);

%Determine solutions
kmax = floor( 0.5*(3*xmax/pi - 1) );
kmin = ceil( 0.5*(3*xmin/pi - 1) );
k = kmin:kmax;
xs = (2*k+1)*pi/3;
nmax = floor( ((xmax+2)/pi - 1)/2 );
nmin = ceil( ((xmin+2)/pi - 1)/2 );
n = nmin:nmax;
xs = [xs,(2*n+1)*pi - 2];
ys = cos(2*xs+1);

plot(x,yL,x,yR);
set(gca,'fontsize',fsize)
legend({'y = cos(2x+1)','y = -cos(x-1)'},'fontsize',fsize);
xlabel('x /radians','fontsize',fsize)
ylabel('y','fontsize',fsize);
title('Solution of cos(2x+1)= -cos(x-1)','fontsize',fsize);
hold on;
plot(xs,ys,'r*');
grid on;
xlim([xmin,xmax]);
print(gcf,'trigsolver5.png','-dpng','-r300');
close(gcf);

%%

%End of code



