%trigonometrica
% GUI which plots the solutions to a trig equation like
%    sin(2x) = 0.5
% using a unit circle diagram and a conventional graph.
% Note: sin(x) is the y compoent of the unit circle
%       cos(x) is the x component of the unit circle
%       tan(x) is the gradient of the unit circle
%

function varargout = trigonometrica(varargin)

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
    'gui_Singleton',  gui_Singleton, ...
    'gui_OpeningFcn', @trigonometrica_OpeningFcn, ...
    'gui_OutputFcn',  @trigonometrica_OutputFcn, ...
    'gui_LayoutFcn',  [] , ...
    'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

%%

% GUI opening function
function trigonometrica_OpeningFcn(hObject, eventdata, handles, varargin)

% Choose default command line output for trigonometrica
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

%Store GUI data in a global structure d
global d
d = handles;

%Update the GUI
update_gui;

%%

% Menu to define the type of trig function (sin, cos, tan)
function MENUtrig_Callback(hObject, eventdata, handles)
update_gui;

%%

% Set n in sin( nx ) = k
function EDITn_Callback(hObject, eventdata, handles)
update_gui;

%%

% Set k in sin( nx) = k
function EDITk_Callback(hObject, eventdata, handles)
update_gui;

%%

% Increment k
function PUSHkplus_Callback(hObject, eventdata, handles)
global d
d.k = d.k + d.dk;
set( d.EDITk,'string',num2str(d.k) );
update_gui;

%%

% Decrement k
function PUSHkminus_Callback(hObject, eventdata, handles)
global d
d.k = d.k - d.dk;
set( d.EDITk,'string',num2str(d.k) );
update_gui;

%%

% Increment n
function PUSHnplus_Callback(hObject, eventdata, handles)
global d
d.n = d.n + d.dn;
set( d.EDITn,'string',num2str(d.n) );
update_gui;

%%

% Decrement n
function PUSHnminus_Callback(hObject, eventdata, handles)
global d
d.n = d.n - d.dn;
set( d.EDITn,'string',num2str(d.n) );
update_gui;

%%

% GUI output function
function varargout = trigonometrica_OutputFcn(hObject, eventdata, handles)
varargout{1} = handles.output;

%%

% Update the GUI
function update_gui
global d

%Fontsize of graph annotation
d.fsize = 20;

%Linewidth of graphs
d.linewidth = 2;

%Hard code the number of data points
d.N = 1000;

%Hard code n and k increments
d.dn = 0.1;
d.dk = 0.1;

%Hard code the trig function menu
d.trig_funcs = {'sin','cos','tan' };
set(d.MENUtrig, 'string', d.trig_funcs);

%Set graph limits
d.xlimits = [0,360];
d.ylimits = [-2,2];

%Get the selected trig function
d.trig_func = d.trig_funcs{ get( d.MENUtrig, 'value' )};

%Get the values of n and k
d.n = str2num( get( d.EDITn,'string' ) );
d.k = str2num( get( d.EDITk,'string' ) );

%Determine solutions to <trig function>(nx) = k
%%% NOTE CURRENTLY AN ISSUE FOR -VE n, hence 
%%% oddness of sine and cosine, and eveness of cosine exploited!
if d.n<0
    n_is_negative = 1;
    d.n = -d.n;
    if strcmp(d.trig_func,'sin') || strcmp(d.trig_func,'tan')
        d.k = -d.k;
    end
else
    n_is_negative = 0;
end
[d.theta,d.theta_solutions,d.f,d.f_solutions,nx] = ...
    multi_value_trig( d.trig_func, [num2str(d.n),'*x'],...
    [num2str(1/d.n),'*x'], d.k, [0,2*pi], d.N );
if n_is_negative == 1;
    d.n = -d.n;
    if strcmp(d.trig_func,'sin') || strcmp(d.trig_func,'tan')
        d.k = -d.k;
        d.f = -d.f;
        d.f_solutions = -d.f_solutions;
    end
end

%Convert angles from radians to degrees
d.theta = d.theta*180/pi;
d.theta_solutions = d.theta_solutions*180/pi;

%Plot the 'wave' graph
axes(d.AXESwave);
cla;
d.wave = plot( d.theta, d.f,'linewidth',d.linewidth );
xlabel('\theta^o')
xlim(d.xlimits);
ylim(d.ylimits);
set(d.AXESwave,'xtick',0:90:360,'ytick',-2:0.5:2 );
title( ['f = ',d.trig_func,'(',num2str(d.n),'\theta)'],'fontsize',d.fsize );
grid on
hold on
plot( d.xlimits,[0,0],'k')
plot( d.xlimits,[d.k,d.k],'r','linewidth',d.linewidth);
set(d.AXESwave,'fontsize',d.fsize )

%Add solutions
plot( d.theta_solutions, d.f_solutions ,'r*' );

%Plot unit circle diagram
axes(d.AXESunitcircle)
cla;
plot( cos( d.theta*pi/180 ), sin( d.theta*pi/180 ), 'b','linewidth',d.linewidth );
hold on
plot( [0,0],[-1.2,1.2],'k')
plot( [-1.2,1.2],[0,0],'k')
set(d.AXESunitcircle,'xtick',[-1,-0.5,0,0.5,1],'ytick',[-1,-0.5,0,0.5,1] );
axis equal
xlim([-1.2,1.2])
ylim([-1.2,1.2])
grid on
title('unit circle','fontsize',d.fsize )
set(d.AXESunitcircle,'fontsize',d.fsize )

%Add solutions of n*theta and theta
plot( cos( d.n*d.theta_solutions*pi/180),sin( d.n*d.theta_solutions*pi/180),'m*' );
plot( cos( d.theta_solutions*pi/180),sin( d.theta_solutions*pi/180),'r*' );
for n=1:length(d.theta_solutions)
    plot([0,cos( d.n*d.theta_solutions(n)*pi/180)],...
        [0,sin( d.n*d.theta_solutions(n)*pi/180)],'m','linewidth',d.linewidth );
    plot([0,cos( d.theta_solutions(n)*pi/180)],...
        [0,sin( d.theta_solutions(n)*pi/180)],'r','linewidth',d.linewidth );
end

%Print solutions in text box
t = [];
if ~isempty(d.theta_solutions)
    for n=1:length(d.theta_solutions)
        t = [t,num2str(d.theta_solutions(n),4),', '];
    end
    %Remove last comma
    t = t(1:end-2);
end
if length(d.theta_solutions) > 5
    set( d.TEXTtheta,'string',t,'fontsize',30 );
elseif length(d.theta_solutions) > 10
    set( d.TEXTtheta,'string',t,'fontsize',20 );
else
    set( d.TEXTtheta,'string',t,'fontsize',40 );
end


%End of code
